==> symfony_6.4.5+dfsg.orig.tar.xz: symfony-6.4.5/src/Symfony/Component/Intl/Resources/data/locales/rw.php <==
<?php

return [
    'Names' => [
        'af' => 'Ikinyafurikaneri',
        'am' => 'Inyamuhariki',
        'ar' => 'Icyarabu',
        'as' => 'Icyasamizi',
        'az' => 'Inyazeribayijani',
        'be' => 'Ikibelarusiya',
        'bg' => 'Urunyabuligariya',
        'bn' => 'Ikibengali',
        'br' => 'Inyebiritoni',
        'bs' => 'Inyebosiniya',
        'ca' => 'Igikatalani',
        'cs' => 'Igiceke',
        'cy' => 'Ikigaluwa',
        'da' => 'Ikidaninwa',
        'de' => 'Ikidage',
        'el' => 'Ikigereki',
        'en' => 'Icyongereza',
        'en_RW' => 'Icyongereza (U Rwanda)',
        'en_TO' => 'Icyongereza (Tonga)',
        'eo' => 'Icyesiperanto',
        'es' => 'Icyesipanyolo',
        'et' => 'Icyesitoniya',
        'eu' => 'Ikibasiki',
        'fa' => 'Inyeperisi',
        'fi' => 'Igifinilande',
        'fo' => 'Inyefaroyizi',
        'fr' => 'Igifaransa',
        'fr_RW' => 'Igifaransa (U Rwanda)',
        'fy' => 'Igifiriziyani',
        'ga' => 'Ikirilandi',
        'gd' => 'Ikigaluwa cy’Igisweduwa',
        'gl' => 'Ikigalisiya',
        'gu' => 'Inyegujarati',
        'he' => 'Igiheburayo',
        'hi' => 'Igihindi',
        'hr' => 'Igikorowasiya',
        'hu' => 'Igihongiriya',
        'hy' => 'Ikinyarumeniya',
        'ia' => 'Ururimi Gahuzamiryango',
        'id' => 'Ikinyendoziya',
        'ie' => 'Uruhuzandimi',
        'is' => 'Igisilande',
        'it' => 'Igitaliyani',
        'ja' => 'Ikiyapani',
        'jv' => 'Inyejava',
        'ka' => 'Inyejeworujiya',
        'km' => 'Igikambodiya',
        'kn' => 'Igikanada',
        'ko' => 'Igikoreya',
        'ku' => 'Inyekuridishi',
        'ky' => 'Inkerigizi',
        'ln' => 'Ilingala',
        'lo' => 'Ikilawotiyani',
        'lt' => 'Ikilituwaniya',
        'lv' => 'Ikinyaletoviyani',
        'mk' => 'Ikimasedoniya',
        'mk_MK' => 'Ikimasedoniya (Masedoniya y’Amajyaruguru)',
        'ml' => 'Ikimalayalami',
        'mn' => 'Ikimongoli',
        'mr' => 'Ikimarati',
        'ms' => 'Ikimalayi',
        'mt' => 'Ikimaliteze',
        'ne' => 'Ikinepali',
        'nl' => 'Ikinerilande',
        'nn' => 'Inyenoruveji [Nyonorusiki]',
        'no' => 'Ikinoruveji',
        'oc' => 'Inyogusitani',
        'or' => 'Inyoriya',
        'pa' => 'Igipunjabi',
        'pl' => 'Igipolone',
        'ps' => 'Impashito',
        'pt' => 'Igiporutugali',
        'ro' => 'Ikinyarumaniya',
        'ru' => 'Ikirusiya',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (U Rwanda)',
        'sa' => 'Igisansikiri',
        'sd' => 'Igisindi',
        'sh' => 'Inyeseribiya na Korowasiya',
        'si' => 'Inyesimpaleze',
        'sk' => 'Igisilovaki',
        'sl' => 'Ikinyasiloveniya',
        'so' => 'Igisomali',
        'sq' => 'Icyalubaniya',
        'sq_MK' => 'Icyalubaniya (Masedoniya y’Amajyaruguru)',
        'sr' => 'Igiseribe',
        'su' => 'Inyesudani',
        'sv' => 'Igisuweduwa',
        'sw' => 'Igiswahili',
        'ta' => 'Igitamili',
        'te' => 'Igitelugu',
        'th' => 'Igitayi',
        'ti' => 'Inyatigirinya',
        'tk' => 'Inyeturukimeni',
        'tr' => 'Igiturukiya',
        'ug' => 'Ikiwiguri',
        'uk' => 'Ikinyayukereni',
        'ur' => 'Inyeyurudu',
        'uz' => 'Inyeyuzubeki',
        'vi' => 'Ikinyaviyetinamu',
        'xh' => 'Inyehawusa',
        'yi' => 'Inyeyidishi',
        'zu' => 'Inyezulu',
    ],
];

==> symfony_6.4.24+dfsg.orig.tar.xz: symfony-6.4.24/src/Symfony/Component/Intl/Resources/data/locales/rw.php <==
<?php

return [
    'Names' => [
        'af' => 'Ikinyafurikaneri',
        'am' => 'Inyamuhariki',
        'ar' => 'Icyarabu',
        'as' => 'Icyasamizi',
        'az' => 'Inyazeribayijani',
        'az_Latn' => 'Inyazeribayijani (Latin)',
        'be' => 'Ikibelarusiya',
        'bg' => 'Urunyabuligariya',
        'bn' => 'Ikibengali',
        'br' => 'Inyebiritoni',
        'bs' => 'Inyebosiniya',
        'bs_Latn' => 'Inyebosiniya (Latin)',
        'ca' => 'Igikatalani',
        'cs' => 'Igiceke',
        'cy' => 'Ikigaluwa',
        'da' => 'Ikidaninwa',
        'de' => 'Ikidage',
        'el' => 'Ikigereki',
        'en' => 'Icyongereza',
        'en_RW' => 'Icyongereza (U Rwanda)',
        'en_TO' => 'Icyongereza (Tonga)',
        'eo' => 'Icyesiperanto',
        'es' => 'Icyesipanyolo',
        'et' => 'Icyesitoniya',
        'eu' => 'Ikibasiki',
        'fa' => 'Inyeperisi',
        'fi' => 'Igifinilande',
        'fo' => 'Inyefaroyizi',
        'fr' => 'Igifaransa',
        'fr_RW' => 'Igifaransa (U Rwanda)',
        'fy' => 'Igifiriziyani',
        'ga' => 'Ikirilandi',
        'gd' => 'Ikigaluwa cy’Igisweduwa',
        'gl' => 'Ikigalisiya',
        'gu' => 'Inyegujarati',
        'he' => 'Igiheburayo',
        'hi' => 'Igihindi',
        'hi_Latn' => 'Igihindi (Latin)',
        'hr' => 'Igikorowasiya',
        'hu' => 'Igihongiriya',
        'hy' => 'Ikinyarumeniya',
        'ia' => 'Ururimi Gahuzamiryango',
        'id' => 'Ikinyendoziya',
        'ie' => 'Uruhuzandimi',
        'is' => 'Igisilande',
        'it' => 'Igitaliyani',
        'ja' => 'Ikiyapani',
        'jv' => 'Inyejava',
        'ka' => 'Inyejeworujiya',
        'km' => 'Igikambodiya',
        'kn' => 'Igikanada',
        'ko' => 'Igikoreya',
        'ku' => 'Inyekuridishi',
        'ky' => 'Inkerigizi',
        'ln' => 'Ilingala',
        'lo' => 'Ikilawotiyani',
        'lt' => 'Ikilituwaniya',
        'lv' => 'Ikinyaletoviyani',
        'mk' => 'Ikimasedoniya',
        'mk_MK' => 'Ikimasedoniya (Masedoniya y’Amajyaruguru)',
        'ml' => 'Ikimalayalami',
        'mn' => 'Ikimongoli',
        'mr' => 'Ikimarati',
        'ms' => 'Ikimalayi',
        'mt' => 'Ikimaliteze',
        'ne' => 'Ikinepali',
        'nl' => 'Ikinerilande',
        'nn' => 'Inyenoruveji [Nyonorusiki]',
        'no' => 'Ikinoruveji',
        'oc' => 'Inyogusitani',
        'or' => 'Inyoriya',
        'pa' => 'Igipunjabi',
        'pl' => 'Igipolone',
        'ps' => 'Impashito',
        'pt' => 'Igiporutugali',
        'ro' => 'Ikinyarumaniya',
        'ru' => 'Ikirusiya',
        'rw' => 'Ikinyarwanda',
        'rw_RW' => 'Ikinyarwanda (U Rwanda)',
        'sa' => 'Igisansikiri',
        'sd' => 'Igisindi',
        'sh' => 'Inyeseribiya na Korowasiya',
        'si' => 'Inyesimpaleze',
        'sk' => 'Igisilovaki',
        'sl' => 'Ikinyasiloveniya',
        'so' => 'Igisomali',
        'sq' => 'Icyalubaniya',
        'sq_MK' => 'Icyalubaniya (Masedoniya y’Amajyaruguru)',
        'sr' => 'Igiseribe',
        'sr_Latn' => 'Igiseribe (Latin)',
        'st' => 'Inyesesoto',
        'su' => 'Inyesudani',
        'su_Latn' => 'Inyesudani (Latin)',
        'sv' => 'Igisuweduwa',
        'sw' => 'Igiswahili',
        'ta' => 'Igitamili',
        'te' => 'Igitelugu',
        'th' => 'Igitayi',
        'ti' => 'Inyatigirinya',
        'tk' => 'Inyeturukimeni',
        'tr' => 'Igiturukiya',
        'ug' => 'Ikiwiguri',
        'uk' => 'Ikinyayukereni',
        'ur' => 'Inyeyurudu',
        'uz' => 'Inyeyuzubeki',
        'uz_Latn' => 'Inyeyuzubeki (Latin)',
        'vi' => 'Ikinyaviyetinamu',
        'xh' => 'Inyehawusa',
        'yi' => 'Inyeyidishi',
        'zu' => 'Inyezulu',
    ],
];
